@@ -8,15 +8,17 @@
 
 using namespace Attica;
 
-class License::Private : public QSharedData
+class Q_DECL_HIDDEN License::Private : public QSharedData
 {
 public:
     int id;
     QString name;
     QUrl url;
 
-    Private() : id(-1)
-    {}
+    Private()
+        : id(-1)
+    {
+    }
 };
 
 License::License()
@@ -36,7 +38,8 @@ License &License::operator=(const Attica::License &other)
 }
 
 License::~License()
-{}
+{
+}
 
 uint License::id() const
 {
